## 台湾电子产业月营收

接口：tmt_twincome

描述：获取台湾TMT电子产业领域各类产品月度营收数据。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | N | 报告期 |
| item | str | Y | 产品代码 |
| start_date | str | N | 报告期开始日期 |
| end_date | str | N | 报告期结束日期 |

输出参数

| 名称 | 类型 | 描述 |
| --- | --- | --- |
| date | str | 报告期 |
| item | str | 产品代码 |
| op_income | str | 月度收入 |

由于服务器压力，单次最多获取30个月数据，后续再逐步全部开放，目前可根据日期范围多次获取数据。

调用代码示例

```python
pro = ts.pro_api()

#获取PCB月度营收
df = pro.tmt_twincome(item='8')

#获取PCB月度营收（20120101-20181010）
df = pro.tmt_twincome(item='8', start_date='20120101', end_date='20181010')
```

数据样例

```python
date item   op_income
0   20180731    8  35144753.0
```

产品代码列表

| TS代码 | 类别名称 |
| --- | --- |
| 1 | PC |
| 2 | NB |
| 3 | 主机板 |
| 4 | 印刷电路板 |
| 5 | IC载板 |
| 6 | PCB组装 |
| 7 | 软板 |
| 8 | PCB |
| 9 | PCB原料 |
| 10 | 铜箔基板 |
| 11 | 玻纤纱布 |
| 12 | FCCL |
| 13 | 显示卡 |
| 14 | 绘图卡 |
| 15 | 电视卡 |
| 16 | 泛工业电脑 |
| 17 | POS |
| 18 | 工业电脑 |
| 19 | 光电IO |
| 20 | 监视器 |
| 21 | 扫描器 |
| 22 | PC周边 |
| 23 | 储存媒体 |
| 24 | 光碟 |
| 25 | 硬盘磁盘 |
| 26 | 发光二极体 |
| 27 | 太阳能 |
| 28 | LCD面板 |
| 29 | 背光模组 |
| 30 | LCD原料 |
| 31 | LCD其它 |
| 32 | 触控面板 |
| 33 | 监控系统 |
| 34 | 其它光电 |
| 35 | 电子零组件 |
| 36 | 二极体整流 |
| 37 | 连接器 |
| 38 | 电源供应器 |
| 39 | 机壳 |
| 40 | 被动元件 |
| 41 | 石英元件 |
| 42 | 3C二次电源 |
| 43 | 网路设备 |
| 44 | 数据机 |
| 45 | 网路卡 |
| 46 | 半导体 |
| 47 | 晶圆制造 |
| 48 | IC封测 |
| 49 | 特用IC |
| 50 | 记忆体模组 |
| 51 | 晶圆材料 |
| 52 | IC设计 |
| 53 | IC光罩 |
| 54 | 电子设备 |
| 55 | 手机 |
| 56 | 通讯设备 |
| 57 | 电信业 |
| 58 | 网路服务 |
| 59 | 卫星通讯 |
| 60 | 光纤通讯 |
| 61 | 3C通路 |
| 62 | 消费性电子 |
| 63 | 照相机 |
| 64 | 软件服务 |
| 65 | 系统整合 |